==> haskell-base-unicode-symbols-0.2.4.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-unicode-symbols
version:              0.2.4.2
visibility:           public
id:                   base-unicode-symbols-0.2.4.2-BaB5bNrnbp75M9kBADhqQy
key:                  base-unicode-symbols-0.2.4.2-BaB5bNrnbp75M9kBADhqQy
license:              BSD-3-Clause
copyright:            2009–2019 Roel van Dijk <roel@lambdacube.nl>
maintainer:           Roel van Dijk <roel@lambdacube.nl>
author:               Roel van Dijk <roel@lambdacube.nl>
stability:            provisional
homepage:             http://haskell.org/haskellwiki/Unicode-symbols
synopsis:             Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.

    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.

    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension [1]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.

    Original idea by P&#xE9;ter Divi&#xE1;nszky.

    \[1] <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/glasgow_exts.html#unicode-syntax>

abi:                  567c1e262c582130ae937a198573cad4
exposed:              True
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Category.Unicode Control.Monad.Unicode Data.Bool.Unicode
    Data.Eq.Unicode Data.Foldable.Unicode Data.Function.Unicode
    Data.List.Unicode Data.Monoid.Unicode Data.Ord.Unicode
    Data.String.Unicode Numeric.Natural.Unicode Prelude.Unicode

import-dirs:          /usr/lib/ghc-8.8.3/site-local/base-unicode-symbols-0.2.4.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/base-unicode-symbols-0.2.4.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.3/base-unicode-symbols-0.2.4.2

hs-libraries:         HSbase-unicode-symbols-0.2.4.2-BaB5bNrnbp75M9kBADhqQy
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock

haddock-html:         /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-unicode-symbols-0.2.4.2-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-unicode-symbols
version:              0.2.4.2
visibility:           public
id:                   base-unicode-symbols-0.2.4.2-vnVOBvjTNUBN7IzyjwGBX
key:                  base-unicode-symbols-0.2.4.2-vnVOBvjTNUBN7IzyjwGBX
license:              BSD-3-Clause
copyright:            2009–2019 Roel van Dijk <roel@lambdacube.nl>
maintainer:           Roel van Dijk <roel@lambdacube.nl>
author:               Roel van Dijk <roel@lambdacube.nl>
stability:            provisional
homepage:             http://haskell.org/haskellwiki/Unicode-symbols
synopsis:             Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.

    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.

    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension [1]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.

    Original idea by P&#xE9;ter Divi&#xE1;nszky.

    \[1] <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/glasgow_exts.html#unicode-syntax>

abi:                  b198c10a667bce6349622e9e314d8d94
exposed:              True
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Category.Unicode Control.Monad.Unicode Data.Bool.Unicode
    Data.Eq.Unicode Data.Foldable.Unicode Data.Function.Unicode
    Data.List.Unicode Data.Monoid.Unicode Data.Ord.Unicode
    Data.String.Unicode Numeric.Natural.Unicode Prelude.Unicode

import-dirs:          /usr/lib/ghc-8.10.1/site-local/base-unicode-symbols-0.2.4.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/base-unicode-symbols-0.2.4.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/base-unicode-symbols-0.2.4.2

hs-libraries:         HSbase-unicode-symbols-0.2.4.2-vnVOBvjTNUBN7IzyjwGBX
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock

haddock-html:         /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
